@@ -4,30 +4,48 @@
 import os
 import execjs  # PyExecJS
 from qsnctf.auxiliary import js_from_file
+import urllib.parse
+import re
+
+
 # 社会主义核心价值观编码
 # 需要将Python目录下>lib>subprocess.py的765行附近的encoding的默认None值修改为utf-8即可。
 
 
-def Chinese_socialism_encode(data):
+def Chinese_socialism_encode(string):
     # 社会主义核心价值观编码
     package_path = os.path.abspath(os.path.dirname(__file__))
     file_path = os.path.join(package_path, 'plugin', 'js', 'cvencode.js')
     content = execjs.compile(js_from_file(file_path))
-    result = content.call('encode', data)
-    result = str(result)
-    return result
+    return str(content.call('encode', string))
 
 
-def Chinese_socialism_decode(data):
+def Chinese_socialism_decode(string):
     # 社会主义核心价值观解码
     package_path = os.path.abspath(os.path.dirname(__file__))
     file_path = os.path.join(package_path, 'plugin', 'js', 'cvencode.js')
     content = execjs.compile(js_from_file(file_path))
-    result = content.call('decode', data)
-    result = str(result)
-    return result
+    return str(content.call('decode', string))
 
 
 def string_reverse(string):
     # 字符串逆向
-    return string[::-1]
\ No newline at end of file
+    return string[::-1]
+
+
+def url_encode(string):
+    # url编码
+    return urllib.parse.quote(string)
+
+
+def url_decode(string):
+    # url解码
+    return urllib.parse.unquote(string)
+
+
+def xor_list(lt_data, lt_root):
+    # 异或 lt_root直接传列表过来，这样也可以字符串之间互相异或
+    decrypted = ""
+    for i in range(min(len(lt_data), len(lt_root))):
+        decrypted += chr(ord(lt_data[i]) ^ ord(lt_root[i]))
+    return decrypted
